package com.example.julian.endlessroll.levels;

import com.example.julian.endlessroll.levels.worlds.World;

import org.simpleframework.xml.Attribute;
import org.simpleframework.xml.Element;
import org.simpleframework.xml.ElementList;
import org.simpleframework.xml.Root;

import java.util.List;

/**
 * Created by Julian on 07.12.2015.
 */
@Root
public class LevelPack {

    @Element
    private World world;
    @ElementList
    private List<Level> levels;
    private boolean locked;

    public List<Level> getLevels() {
        return levels;
    }

    public int getUnlockedLevels(){
        int count = 0;
        for(Level level : levels)
            if(level.isUnlocked())
                count++;
        return count;
    }

    public int getCollectedStars(){
        int count = 0;
        for(Level level : levels)
            count += level.getCollectedStars().length();
        return count;
    }

    public int getAvailableStars(){
        return levels.size() * 3;
    }

    public World getWorld() {
        return world;
    }

    public void tryToUnlockFirstLevel() {
        try {
            levels.get(0).setUnlocked(true);
        } catch (Exception e) {
        }
    }

    public Level getLevel(int number) {
        for (Level level : levels)
            if (level.getNumber() == number)
                return level;
        return null;
    }

    public Level getNextLevel(Level currentLevel) {
        if (isLastLevel(currentLevel)) {
            return null;
        }
        int index = levels.indexOf(currentLevel);
        return levels.get(index + 1);
    }

    public boolean isLastLevel(Level level) {
        int index = levels.indexOf(level);
        return levels.size() == index + 1;
    }

    public void reset(){
        for(Level level : levels){
            level.reset();
        }
        tryToUnlockFirstLevel();
    }

    public void setLocked(boolean locked) {
        this.locked = locked;
    }

    public boolean isLocked() {
        return locked;
    }
}
