package com.example.julian.endlessroll.levels.worlds;

import android.support.annotation.DrawableRes;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.entities.textures.Texture;
import com.example.julian.endlessroll.entities.textures.TexturePack;

/**
 * Created by Julian on 14.11.2016.
 */

public enum World {

    GRASSLANDS(0, "Grasslands", R.drawable.grasslands_preview, R.drawable.background, R.drawable.terrain, R.drawable.obstacle),
    TESTCAVE(1, "Testcave", R.drawable.grasslands_preview, R.drawable.background_cave, R.drawable.terrain, R.drawable.obstacle),
    ICY_MOUNTAINS(2, "Icy Mountains", R.drawable.grasslands_preview, R.drawable.background_icymountains, R.drawable.terrain, R.drawable.obstacle);

    private int index;
    private String name;
    @DrawableRes
    private int previewId;
    @DrawableRes
    private int backgroundId;
    @DrawableRes
    private int terrainId;
    @DrawableRes
    private int obstacleId;

    private Texture background;
    private Texture terrain;
    private Texture obstacle;

    World(int index, String name, @DrawableRes int previewId, @DrawableRes int backgroundId, @DrawableRes int terrainId, @DrawableRes int obstacleId) {
        this.index = index;
        this.name = name;
        this.previewId = previewId;
        this.backgroundId = backgroundId;
        this.terrainId = terrainId;
        this.obstacleId = obstacleId;
    }

    public static void loadAllSpecificTextures(TexturePack texturePack){
        for(World world : values())
            world.loadSpecificTextures(texturePack);
    }

    private void loadSpecificTextures(TexturePack texturePack) {
        background = texturePack.loadTexture(backgroundId);
        terrain = texturePack.loadTexture(terrainId);
        obstacle = texturePack.loadAtlas(obstacleId, 2, 2);
    }

    public int getIndex() {
        return index;
    }

    public String getName() {
        return name;
    }

    public int getPreviewId() {
        return previewId;
    }

    public Texture getBackgroundTexture() {
        return background;
    }

    public Texture getTerrainTexture() {
        return terrain;
    }

    public Texture getObstacleTexture() {
        return obstacle;
    }
}
